==> php-residence_0.2.4.tar.gz: php-residence/includes/lang/en/disponibilita.php <==
<?php

switch ($messaggio) {

case "Le date sono sbagliate":  		$messaggio = "Dates are wrong"; break;
case "Non c' nessun appartamento che possa ospitare":	$messaggio = "There are no apartments that can accomodate"; break;
case "persone":  				$messaggio = "people"; break;
case "Non c' nessun appartamento da":  	$messaggio = "There are no apartments of"; break;
case "La settimana dal":  			$messaggio = "The week from"; break;
case "Il giorno dal":  				$messaggio = "The day from"; break;
case "al":  					$messaggio = "to"; break;
case " piena":  				$messaggio = "is full"; break;
case " pieno":  				$messaggio = "is full"; break;
case "<b>C'</b> ancora disponibilit nel periodo richiesto":	$messaggio = "<b>There is</b> still availability in the requested period"; break;
case " in appartamenti da <b>almeno":  		$messaggio = " in apartment of <b>at least"; break;
case " in appartamenti da":  			$messaggio = " in apartments of"; break;
case ", ma si dovr occupare uno o pi appartamenti della <b>regola di assegnazione 1</b>":	$messaggio = ", but one or more apartments from <b>assignation rule 1</b> will have to be occupied"; break;
case "<b>Non c'</b> pi disponibilit nel periodo richiesto":	$messaggio = "<b>There is not</b> availability in the requested period any more"; break;
case "Si potrebbe inserire la prenotazione dividendola in":	$messaggio = "The reservation could be inserted breaking it into"; break;
case "parti":  					$messaggio = "pieces"; break;
case "Periodo di":  				$messaggio = "Period of"; break;
case "dal":  					$messaggio = "from"; break;
case "settimane":  				$messaggio = "weeks"; break;
case "giorni":  				$messaggio = "days"; break;
case "Tariffa":  				$messaggio = "Fare"; break;
case "compresi":  				$messaggio = "including"; break;
case "di costi aggiuntivi fissi":  		$messaggio = "of fixed extra costs"; break;
case "Ricontrolla":  				$messaggio = "Check again"; break;
case "la disponibilit solo negli appartamenti da":	$messaggio = "the availability only in apartments of"; break;
case "Torna al men principale":  		$messaggio = "Back to main menu"; break;
case "Visualizza il contratto":  		$messaggio = "View contract"; break;
case "di tipo":  				$messaggio = "type"; break;
case "con la tariffa":  			$messaggio = "with fare"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> php-residence_0.3.tar.gz: php-residence/includes/lang/en/disponibilita.php <==
<?php

switch ($messaggio) {

case "Le date sono sbagliate":  		$messaggio = "Dates are wrong"; break;
case "Non c' nessun appartamento che possa ospitare":	$messaggio = "There are no apartments that can accomodate"; break;
case "persone":  				$messaggio = "people"; break;
case "Non c' nessun appartamento da":  	$messaggio = "There are no apartments of"; break;
case "La settimana dal":  			$messaggio = "The week from"; break;
case "Il giorno dal":  				$messaggio = "The day from"; break;
case "al":  					$messaggio = "to"; break;
case " piena":  				$messaggio = "is full"; break;
case " pieno":  				$messaggio = "is full"; break;
case "<b>C'</b> ancora disponibilit nel periodo richiesto":	$messaggio = "<b>There is</b> still availability in the requested period"; break;
case " in appartamenti da <b>almeno":  		$messaggio = " in apartment of <b>at least"; break;
case " in appartamenti da":  			$messaggio = " in apartments of"; break;
case ", ma si dovranno fare degli spostamenti nei periodi della <font color=\"blue\">regola di assegnazione 1</font>":	$messaggio = ", but some movements will have to be made in periods of <font color=\"blue\">assignation rule 1</font>"; break;
case "<b>Non c'</b> pi disponibilit nel periodo richiesto":	$messaggio = "<b>There is not</b> availability in the requested period any more"; break;
case "Si potrebbe inserire la prenotazione dividendola in":	$messaggio = "The reservation could be inserted breaking it into"; break;
case "parti":  					$messaggio = "pieces"; break;
case "Periodo di":  				$messaggio = "Period of"; break;
case "dal":  					$messaggio = "from"; break;
case "settimane":  				$messaggio = "weeks"; break;
case "giorni":  				$messaggio = "days"; break;
case "Tariffa":  				$messaggio = "Fare"; break;
case "compresi":  				$messaggio = "including"; break;
case "di costi aggiuntivi fissi":  		$messaggio = "of fixed extra costs"; break;
case "Ricontrolla":  				$messaggio = "Check again"; break;
case "la disponibilit solo negli appartamenti da":	$messaggio = "the availability only in apartments of"; break;
case "Torna al men principale":  		$messaggio = "Back to main menu"; break;
case "Visualizza il contratto":  		$messaggio = "View contract"; break;
case "di tipo":  				$messaggio = "type"; break;
case "con la tariffa":  			$messaggio = "with fare"; break;
case "Inserisci la prenotazione":  		$messaggio = "Insert the reservation"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
